==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QInputSettings.java <==
package io.qt.qt3d.input;


/**
 * <p>Holds the pointer to an input event source object</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsettings.html">Qt3DInput::QInputSettings</a></p>
 */
public class QInputSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcEventSource = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputSettings.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::eventSourceChanged(QObject*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="eventSource")
    public final Signal1<io.qt.core.QObject> eventSourceChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QInputSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QInputSettings(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::eventSource()const</a></p>
     */
    @io.qt.QtPropertyReader(name="eventSource")
    @io.qt.QtUninvokable
    public final io.qt.core.QObject eventSource(){
        return eventSource_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QObject eventSource_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::setEventSource(QObject*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="eventSource")
    public final void setEventSource(io.qt.core.QObject eventSource){
        setEventSource_native_QObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(eventSource));
        __rcEventSource = eventSource;
    }
    
    private native void setEventSource_native_QObject_ptr(long __this__nativeId, long eventSource);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputSettings instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.4.0-sources.jar: io/qt/qt3d/input/QInputSettings.java <==
package io.qt.qt3d.input;


/**
 * <p>Holds the pointer to an input event source object</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html">Qt3DInput::QInputSettings</a></p>
 */
public class QInputSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcEventSource = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputSettings.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::eventSourceChanged(QObject*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="eventSource")
    public final Signal1<io.qt.core.QObject> eventSourceChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QInputSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QInputSettings(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::eventSource()const</a></p>
     */
    @io.qt.QtPropertyReader(name="eventSource")
    @io.qt.QtUninvokable
    public final io.qt.core.QObject eventSource(){
        return eventSource_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QObject eventSource_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::setEventSource(QObject*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="eventSource")
    public final void setEventSource(io.qt.core.QObject eventSource){
        setEventSource_native_QObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(eventSource));
        __rcEventSource = eventSource;
    }
    
    private native void setEventSource_native_QObject_ptr(long __this__nativeId, long eventSource);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputSettings instance, QDeclarativeConstructor constructor);
    
}
